@@ -21,12 +21,25 @@
 #define SIDEBARMODE_H
 
 #include "BaseMode.h"
+#include <QWidget>
 
 class ModuleView;
 class KAboutData;
 class QModelIndex;
 class QAbstractItemView;
 class QAbstractItemModel;
+class QAction;
+
+class FocusHackWidget : public QWidget {
+    Q_OBJECT
+public:
+    FocusHackWidget(QWidget *parent = nullptr);
+    ~FocusHackWidget();
+
+public Q_SLOTS:
+    void focusNext();
+    void focusPrevious();
+};
 
 class SidebarMode : public BaseMode
 {
@@ -59,7 +72,9 @@ public:
 
     int width() const;
 
-    Q_INVOKABLE void triggerGlobalAction(const QString &name);
+    Q_INVOKABLE QAction *action(const QString &name) const;
+    // QML doesn't understand QIcon, otherwise we could get it from the QAction itself
+    Q_INVOKABLE QString actionIconName(const QString &name) const;
     Q_INVOKABLE void requestToolTip(int index, const QRectF &rect);
     Q_INVOKABLE void hideToolTip();
     Q_INVOKABLE void loadMostUsed(int index);
